[python sdk index](https://cloud.google.com/python/docs/reference)
# Dependencies graph
- `google-auth`
- `google-cloud-core`: optional in extra `davidkhala.gcp[core]`
    - It includes `google-api-core`
- `google-api-core`         